# 1.1.0 (2025-10-20)

Drop support for `python3.9`

* **Clustering:** Add clustering.
* **Classifiers:** Add classifiers macrolib as dependency.
* **Linear regression:** Add `tno.quantum.ml.regression.linear_regression`

# 1.0.0 (2025-05-12)

### Initial release

* **Datasets:** Add datasets.
* **Variational Classifier:** Add variational classifier.